<?php

/*
* Neato Botvac Api.
* Helper class to make requests against Neato API
*
* PHP port based on https://github.com/kangguru/botvac
*
* Author: Tom Rosenback tom.rosenback@gmail.com  2016
*/

class NeatoBotvacApi {
	public static function request($url, $payload = array(), $method = "POST", $headers = array()) {
		$ch = curl_init($url);

		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);

		if($method == "POST") {
			curl_setopt($ch, CURLOPT_POSTFIELDS, $payload);
		}

		$requestHeaders = array(
			'Accept: application/vnd.neato.nucleo.v1'
		);

		if(count($headers) > 0) {
			$requestHeaders = array_merge($requestHeaders, $headers);
		}

		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_HTTPHEADER, $requestHeaders);

		$result = curl_exec($ch);
		curl_close($ch);

		return json_decode($result, true);
	}
}
class NeatoBotvacRobot {
	protected $baseUrl = "https://nucleo.neatocloud.com/vendors/neato/robots/";
	protected $serial;
	protected $secret;

	public function __construct($serial, $secret) {
		$this->serial = $serial;
		$this->secret = $secret;
	}

	public function getState() {
		return $this->doAction("getRobotState");
	}

	public function startCleaning($eco = false) {
		$params = array("category" => 2, "mode" => ($eco ? 1 : 2), "modifier" => 2);
		return $this->doAction("startCleaning", $params);
	}
	
	public function startEcoCleaning() {
		$params = array("category" => 2, "mode" => 1, "modifier" => 2);
		return $this->doAction("startCleaning", $params);
	}

	public function pauseCleaning() {
		return $this->doAction("pauseCleaning");
	}
	
	public function resumeCleaning() {
		return $this->doAction("resumeCleaning");
	}

	public function stopCleaning() {
		return $this->doAction("stopCleaning");
	}

	public function sendToBase() {
		return $this->doAction("sendToBase");
	}

	public function enableSchedule() {
		return $this->doAction("enableSchedule");
	}

	public function disableSchedule() {
		return $this->doAction("disableSchedule");
	}

	public function getSchedule() {
		return $this->doAction("getSchedule");
	}

	protected function doAction($command, $params = false) {
		$result = array("message" => "no serial or secret");

		if($this->serial !== false && $this->secret !== false) {
			$payload = array("reqId" => "1", "cmd" => $command);

			if($params !== false) {
				$payload["params"] = $params;
			}

			$payload = json_encode($payload);
			$date = gmdate("D, d M Y H:i:s")." GMT";
			$data = implode("\n", array(strtolower($this->serial), $date, $payload));
			$hmac = hash_hmac("sha256", $data, $this->secret);

			$headers = array(
	    	"Date: ".$date,
	    	"Authorization: NEATOAPP ".$hmac
			);

			$result = NeatoBotvacApi::request($this->baseUrl.$this->serial."/messages", $payload, "POST", $headers);
		}

		return $result;
	}


}
$serial = "votrenumérodeserie";
$secret = "votresecretkey";

$robot = new NeatoBotvacRobot($serial, $secret);
print_r($robot->startCleaning());

// sleep(20);
// print_r($robot->pauseCleaning());
// print_r($robot->sendToBase());
?>